<?php

/**
 * @file
 * Drush commands for sml_lesson
 */

use Drupal\ptools\Queue\QueueHandlerFactory;

/**
 * Implements hook_drush_command().
 */
function ptools_drush_command() {
  $items = [];

  $items['ptools-queue-items'] = [
    'description' => 'Queues up some items in the specified queues. A comma separated list of items is accepted, if no item is specified all items are queued up.',
    'bootstrap' => DRUSH_BOOTSTRAP_DRUPAL_FULL,
    'aliases' => ['pt-qi'],
  ];

  $items['ptools-queue-clear'] = [
    'description' => 'Clears the specified queue.',
    'bootstrap' => DRUSH_BOOTSTRAP_DRUPAL_FULL,
    'aliases' => ['pt-qc'],
  ];

  $items['ptools-queue-process'] = [
    'description' => 'Processes the specified queue.',
    'bootstrap' => DRUSH_BOOTSTRAP_DRUPAL_FULL,
    'aliases' => ['pt-qp'],
    'options' => [
      'limit' => 'Limits the processing to the specified amount of items.',
      'time-limit' => 'Limits the processing to the specified amount of seconds.',
    ],
  ];

  $items['ptools-queue-size'] = [
    'description' => 'Prints the amount of queued items to "stdout".',
    'bootstrap' => DRUSH_BOOTSTRAP_DRUPAL_FULL,
    'aliases' => ['pt-qs'],
  ];

  return $items;
}

/**
 * Queues the specified items for processing.
 *
 * @param string $queue_name
 *   The queue name.
 * @param string|null $items
 *   (optional) A comma-separated list of items. Defaults to queueing all
 *   pending items.
 */
function drush_ptools_queue_items($queue_name, $items = NULL) {
  if (is_string($items)) {
    $items = array_map('trim', explode(',', $items));
  }
  QueueHandlerFactory::get()
    ->getQueueHandler($queue_name)
    ->queueItems($items);
}

/**
 * Clears the specified queue.
 *
 * @param string $queue_name
 *   The queue name.
 */
function drush_ptools_queue_clear($queue_name) {
  QueueHandlerFactory::get()
    ->getQueueHandler($queue_name)
    ->clearQueue();
}

/**
 * Processes the specified queue.
 *
 * @param string $queue_name
 *   The queue name.
 */
function drush_ptools_queue_process($queue_name) {
  $limit = drush_get_option('limit');
  $time_limit = drush_get_option('time-limit');
  QueueHandlerFactory::get()
    ->getQueueHandler($queue_name)
    ->processItems($limit, $time_limit);
}

/**
 * Prints the amount of queued items to "stdout".
 *
 * @param string $queue_name
 *   The queue name.
 */
function drush_ptools_queue_size($queue_name) {
  /** @var \DrupalQueueInterface $queue */
  $queue = \DrupalQueue::get($queue_name);
  print $queue->numberOfItems() . "\n";
}
