<?php

namespace Drupal\ptools;

/**
 * Trait useful to use Database connections.
 *
 * @see \db_query()
 * @see \db_select()
 */
trait DatabaseConnectionTrait {

  /**
   * The database connection.
   *
   * @var \DatabaseConnection
   */
  protected $database;

  /**
   * Prepares and returns a SELECT query object.
   *
   * @param $table
   *   The base table for this query, that is, the first table in the FROM
   *   clause. This table will also be used as the "base" table for query_alter
   *   hook implementations.
   * @param $alias
   *   The alias of the base table of this query.
   * @param $options
   *   An array of options on the query.
   *
   * @return \SelectQuery
   *   A select query.
   *
   * @see \DatabaseConnection::select()
   */
  protected function getSelectQuery($table, $alias = NULL, array $options = array()) {
    /** @var \SelectQuery $select */
    $select = $this->database->select($table, $alias, $options);
    return $select;
  }

}
