<?php

namespace Drupal\ptools\Form;

/**
 * Common interface for form-processing classes.
 */
interface FormProcessorInterface {

  /**
   * Builds a form array.
   *
   * @param array $form
   *   The initial form array.
   * @param array $form_state
   *   The initial form state array.
   * @param array ...$args
   *   Any extra arguments passed to the form.
   *
   * @return array
   *   The form array.
   */
  public function buildForm(array $form, array &$form_state, ...$args);

  /**
   * Processes a form array.
   *
   * @param array $form
   *   The form array.
   * @param array $form_state
   *   The form state array.
   *
   * @return array
   *   The processed form array.
   */
  public function processForm(array $form, array &$form_state);

  /**
   * Form validation handler.
   *
   * @param array $form
   *   The form array.
   * @param array $form_state
   *   The form state array.
   */
  public function validateForm(array $form, array &$form_state);

  /**
   * Form submission handler.
   *
   * @param array $form
   *   The form array.
   * @param array $form_state
   *   The form state array.
   */
  public function submitForm(array $form, array &$form_state);

}
