<?php

namespace Drupal\ptools\Plugin;

/**
 * Applicable plugin factory.
 */
class ApplicablePluginFactory extends PluginFactory implements ApplicablePluginFactoryInterface {

  /**
   * {@inheritdoc}
   */
  public function getApplicablePlugins($context) {
    $plugins = [];
    foreach ($this->getPlugins() as $plugin) {
      if ($this->isPluginApplicable($plugin, $context)) {
        $plugins[] = $plugin;
      }
    }
    if ($plugins) {
      return $plugins;
    }
    throw new InvalidApplicablePluginContextException($context);
  }

  /**
   * {@inheritdoc}
   */
  public function getFirstApplicablePlugin($context) {
    foreach ($this->getPlugins() as $plugin) {
      if ($this->isPluginApplicable($plugin, $context)) {
        /** @var \Drupal\ptools\Plugin\ApplicablePluginInterface $plugin */
        return $plugin;
      }
    }
    throw new InvalidApplicablePluginContextException($context);
  }

  /**
   * Check whether this plugin is applicable to the specified context.
   *
   * @param object $plugin
   *   A plugin instance.
   * @param mixed $context
   *   Arbitrary data useful to determine applicability.
   *
   * @return bool
   *   TRUE if the plugin applies to the specified context, FALSE otherwise.
   */
  protected function isPluginApplicable($plugin, $context) {
    return $plugin instanceof ApplicablePluginInterface && $plugin->appliesTo($context);
  }

}
