<?php

namespace Drupal\ptools\Plugin;

/**
 * Applicable plugin factory.
 */
interface ApplicablePluginFactoryInterface extends PluginFactoryInterface {

  /**
   * Returns a set of plugin instances suitable for the specified context.
   *
   * @param mixed $context
   *   Arbitrary data to be forwarded to plugin instances and useful to
   *   determine a matching plugin instance.
   *
   * @return \Drupal\ptools\Plugin\ApplicablePluginInterface[]
   *   An array of plugin instances matching the specified context.
   *
   * @throws \Drupal\ptools\Plugin\InvalidApplicablePluginContextException
   *   If no matching plugin instance was found.
   */
  public function getApplicablePlugins($context);

  /**
   * Returns the first plugin instance suitable for the specified context.
   *
   * @param mixed $context
   *   Arbitrary data to be forwarded to plugin instances and useful to
   *   determine a matching plugin instance.
   *
   * @return \Drupal\ptools\Plugin\ApplicablePluginInterface
   *   A plugin instance matching the specified context.
   *
   * @throws \Drupal\ptools\Plugin\InvalidApplicablePluginContextException
   *   If no matching plugin instance was found.
   */
  public function getFirstApplicablePlugin($context);

}
