<?php

namespace Drupal\ptools\Plugin;

use Drupal\ptools\SingletonTrait;

/**
 * Generic plugin factory.
 */
class PluginFactory implements PluginFactoryInterface {

  /**
   * The module defining the plugin type.
   *
   * @var string
   */
  protected $module;

  /**
   * The plugin type.
   *
   * @var string
   */
  protected $pluginType;

  /**
   * Static cache of plugin instances.
   *
   * @var object[]
   */
  protected $plugins;

  /**
   * PluginFactory constructor.
   *
   * @param string $module
   *   The module defining the plugin type.
   * @param string $plugin_type
   *   The plugin type.
   */
  public function __construct($module, $plugin_type) {
    $this->module = $module;
    $this->pluginType = $plugin_type;
  }

  /**
   * {@inheritdoc}
   */
  public function getPlugin($name) {
    $this->getPlugins();
    if (isset($this->plugins[$name])) {
      return $this->plugins[$name];
    }
    throw new \InvalidArgumentException(format_string('Undefined plugin: @name', ['@name' => $name]));
  }

  /**
   * {@inheritdoc}
   */
  public function getPlugins() {
    if (!isset($this->plugins)) {
      $this->plugins = [];
      ctools_include('plugins');
      $definitions = ctools_get_plugins($this->module, $this->pluginType);
      $weighted = TRUE;
      foreach ($definitions as $definition) {
        $plugin = $this->getPluginFromDefinition($definition);
        if (!($plugin instanceof WeightedPluginInterface)) {
          $weighted = FALSE;
        }
        $this->plugins[$definition['name']] = $plugin;
      }
      if ($weighted) {
        $plugins = &$this->plugins;
        uksort($plugins, function ($a_key, $b_key) use ($plugins) {
          return $plugins[$a_key]->getWeight() - $plugins[$b_key]->getWeight();
        });
      }
    }
    return $this->plugins;
  }

  /**
   * Returns a plugin instance.
   *
   * @param array $definition
   *   The plugin definition.
   *
   * @return object
   *   A plugin instance.
   */
  protected function getPluginFromDefinition($definition) {
    ctools_include('plugins');
    $handler_class = ctools_plugin_get_class($definition, 'handler');
    if (in_array(SingletonTrait::class, class_uses($handler_class))) {
      /** @var \Drupal\ptools\SingletonTrait $handler_class */
      return $handler_class::get(['definition' => $definition]);
    }
    else {
      return new $handler_class($definition);
    }
  }

}
