<?php

namespace Drupal\ptools\Queue;

use Drupal\ptools\Plugin\PluginFactory;
use Drupal\ptools\Plugin\PluginFactoryInterface;
use Drupal\ptools\SingletonTrait;

/**
 * The queue handler factory.
 */
class QueueHandlerFactory {
  use SingletonTrait;

  /**
   * The plugin factory.
   *
   * @var \Drupal\ptools\Plugin\PluginFactoryInterface
   */
  protected $pluginFactory;

  /**
   * QueueHandlerFactory constructor.
   *
   * @param \Drupal\ptools\Plugin\PluginFactoryInterface $plugin_factory
   *   The plugin factory.
   */
  public function __construct(PluginFactoryInterface $plugin_factory) {
    $this->pluginFactory = $plugin_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(array $context = []) {
    return new static(
      new PluginFactory('ptools', 'queue_handler')
    );
  }

  /**
   * Returns a queue handler instance.
   *
   * @param string $queue_name
   *   The queue name.
   *
   * @return \Drupal\ptools\Queue\QueueHandlerInterface
   *   A queue handler instance.
   */
  public function getQueueHandler($queue_name) {
    $queue_handler = $this->pluginFactory->getPlugin($queue_name);
    if ($queue_handler instanceof QueueHandlerInterface) {
      $queue = \DrupalQueue::get($queue_name);
      $queue_handler->setQueueContext($queue_name, $queue);
      return $queue_handler;
    }
    throw new \InvalidArgumentException(format_string('No handler found for queue @name', ['@name' => $queue_name]));
  }

}
