<?php

namespace Drupal\ptools\Queue;

/**
 * Common interface for queue handlers.
 */
interface QueueHandlerInterface {

  /**
   * Sets the queue context.
   *
   * @param string $queue_name
   *   The queue name.
   * @param \DrupalQueueInterface $queue
   *   The handled queue.
   */
  public function setQueueContext($queue_name, \DrupalQueueInterface $queue);

  /**
   * Queues the specified items for processing..
   *
   * @param mixed[]|null $items
   *   (optional) An array of item to be processed. Defaults to queueing all
   *   pending items.
   */
  public function queueItems(array $items = NULL);

  /**
   * Processes the queued items.
   *
   * @param int $limit
   *   (optional) The maximum number of items that should be processed. Defaults
   *   to no limit.
   * @param int $time_limit
   *   (optional) The maximum number of seconds processing should run. Defaults
   *   to no limit.
   *
   * @return int
   *   The number of items actually processed.
   */
  public function processItems($limit = -1, $time_limit = NULL);

  /**
   * Clears the shadow standards update queue.
   */
  public function clearQueue();

}
