<?php

namespace Drupal\ptools\Repository;

use Database;
use Drupal\ptools\SingletonTrait;

/**
 * A taxonomy term repository.
 */
class TaxonomyTermRepository extends RepositoryBase {

  use SingletonTrait;

  /**
   * {@inheritdoc}
   */
  public static function create() {
    return new static(Database::getConnection());
  }

  /**
   * Returns a taxonomy term ID matching the specified vocabulary and name.
   *
   * This assumes only one term with the specified name is available in the
   * specified vocabulary. If no vocabulary is specified the term name is
   * assumed to be unique across all vocabularies.
   *
   * @param string $name
   *   A term name.
   * @param string $vocabulary_name
   *   A vocabulary machine name.
   *
   * @return int|null
   *   A term ID or NULL if none could be found.
   */
  public function getTermIdByName($name, $vocabulary_name = NULL) {
    $cache = &$this->getStaticCache(__FUNCTION__, []);
    $tid = &$cache[$name][$vocabulary_name ?: ''];

    if (!isset($tid)) {
      $query = $this->getSelectQuery('taxonomy_term_data', 't')
        ->fields('t', ['tid'])
        ->condition('t.name', $name)
        ->range(0, 1);

      if ($vocabulary_name) {
        $vocabulary = taxonomy_vocabulary_machine_name_load($vocabulary_name);
        $query->condition('t.vid', $vocabulary->vid);
      }

      $result = $query
        ->execute()
        ->fetchField();

      $tid = $result ? (int) $result : 0;
    }

    return $tid ?: NULL;
  }

}
