<?php

namespace Drupal\ptools\Repository;

use Database;
use Drupal\ptools\SingletonTrait;

/**
 * Drupal user entity repository.
 */
class UserRepository extends RepositoryBase {

  use SingletonTrait;

  /**
   * {@inheritdoc}
   */
  public static function create() {
    return new static(Database::getConnection());
  }

  /**
   * Returns the IDs of all the users matching the specified property values.
   *
   * @param array $values
   *   An array of user property values.
   * @param string $property
   *   The name of the property to be matched.
   *
   * @return int[]
   *   An associative array property values keyed by user ID.
   */
  public function getUserIds(array $values, $property = 'name') {
    return $this->getSelectQuery('users', 'u')
      ->fields('u', ['uid', $property])
      ->condition('u.' . $property, $values)
      ->execute()
      ->fetchAllKeyed();
  }

}
