<?php

namespace Drupal\ptools;

/**
 * Trait useful to implement the singleton pattern.
 */
trait SingletonTrait {

  /**
   * The singleton instance.
   *
   * @var static
   */
  protected static $instance;

  /**
   * Returns the singleton instance.
   *
   * This method should be overridden when the constructor has arguments.
   *
   * @param array $context
   *   (optional) An associative array of additional dependencies. Defaults to
   *   none.
   *
   * @return static
   *   The singleton instance.
   */
  public static function get(array $context = []) {
    if (!isset(static::$instance)) {
      static::$instance = static::create($context);
    }
    return static::$instance;
  }

  /**
   * Actually instantiates the object.
   *
   * @param array $context
   *   (optional) An associative array of additional dependencies. Defaults to
   *   none.
   *
   * @return static
   *   An object instance.
   */
  public static function create(array $context = []) {
    return new static();
  }

  /**
   * Ensures that a new object will be instantiated the next time.
   */
  public static function reset() {
    static::$instance = NULL;
  }

}
