<?php

namespace Drupal\ptools;

/**
 * Trait useful to reuse Drupal's static cache in classes.
 *
 * @see \drupal_static()
 * @see \drupal_static_reset()
 */
trait StaticCacheTrait {

  /**
   * A collection of fetched cache items.
   *
   * @var bool[]
   */
  protected $fetchedCacheItems = [];

  /**
   * Returns a statically cached item.
   *
   * @param string $name
   *   A locally unique cache item name.
   * @param mixed $default
   *   (optional) Default value.
   *
   * @return mixed
   *   A reference to the cache item.
   */
  protected function &getStaticCache($name, $default = NULL) {
    $this->fetchedCacheItems[$name] = TRUE;
    return drupal_static(static::class . '::' . $name, $default);
  }

  /**
   * Resets the specified static cache item.
   *
   * @param string $name
   *   (optional) A locally unique cache item name. If none is provided all
   *   cached items are cleared.
   */
  public function resetStaticCache($name = NULL) {
    if (isset($name)) {
      drupal_static_reset(static::class . '::' . $name);
    }
    else {
      foreach ($this->fetchedCacheItems as $name => $fetched) {
        $this->resetStaticCache($name);
      }
    }
  }

}
